@@ -14,7 +14,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 
 use Rose::DB::Object::Constants qw(PRIVATE_PREFIX);
 
-our $VERSION = '0.779';
+our $VERSION = '0.781';
 
 our $Debug = 0;
 
@@ -23,6 +23,7 @@ __PACKAGE__->default_auto_method_types(qw(find get_set_on_save add_on_save));
 __PACKAGE__->add_common_method_maker_argument_names
 (
   qw(share_db map_class map_from map_to manager_class manager_method
+     manager_count_method manager_iterator_method manager_find_method
      manager_args query_args map_record_method)
 );
 
@@ -728,6 +729,14 @@ Get or set the name of the L<Rose::DB::Object::Manager>-derived class that the L
 
 Get or set the name of the L<manager_class|/manager_class> class method to call when fetching records.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<get_objects|Rose::DB::Object::Manager/get_objects> if this value is left undefined.
 
+=item B<manager_count_method [METHOD]>
+
+Get or set the name of the L<manager_class|/manager_class> class method to call when counting objects.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<get_objects_count|Rose::DB::Object::Manager/get_objects_count> if this value is left undefined.
+
+=item B<manager_iterator_method [METHOD]>
+
+Get or set the name of the L<manager_class|/manager_class> class method to call when creating an iterator.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<get_objects_iterator|Rose::DB::Object::Manager/get_objects_iterator> if this value is left undefined.
+
 =item B<manager_args [HASHREF]>
 
 Get or set a reference to a hash of name/value arguments to pass to the L<manager_method|/manager_method> when fetching objects.  For example, this can be used to enforce a particular sort order for objects fetched via this relationship.  Modifying the L<example|/EXAMPLE> above:
